AutoDefaultConfigProvider

Struct AutoDefaultConfigProvider 

pub struct AutoDefaultConfigProvider<'p, A: Serialize, F: Fn() -> A> { /* private fields */ }
Generates default configurations by combining two things:

  • general config options, provided by a function F
  • the default config of every plugin that is enabled in a PluginSet

Config structure

The generated configuration follows what is expected by PluginSet::extract_config and other agent-related functions. Refer to the module documentation for more information.

Implementations

Source

impl<'p, A: Serialize, F: Fn() -> A> AutoDefaultConfigProvider<'p, A, F>

pub fn new(plugins: &'p PluginSet, default_general_options: F) -> Self

Creates a new default config provider that use the given plugins and general options.

See the structure documentation for more details.